@@ -1,3 +1,4 @@
+import eventlet
 from kombu.message import Message
 from mock import patch
 import pytest
@@ -5,7 +6,7 @@ import socket
 
 from nameko.containers import WorkerContext
 from nameko.dependencies import injection, InjectionProvider, DependencyFactory
-from nameko.exceptions import RemoteError
+from nameko.exceptions import RemoteError, RpcTimeout
 from nameko.rpc import rpc, Responder
 from nameko.standalone.rpc import RpcProxy
 from nameko.testing.utils import get_rabbit_connections
@@ -46,6 +47,11 @@ class FooService(object):
     def get_context_data(self, name):
         return self.get_context_value(name)
 
+    @rpc
+    def sleep(self, seconds=0):
+        eventlet.sleep(seconds)
+        return seconds
+
 
 class ExampleError(Exception):
     pass
@@ -100,7 +106,7 @@ def test_proxy_worker_context(container_factory, rabbit_config):
     context_data = {'custom_header': 'custom_value'}
 
     with RpcProxy('foobar', rabbit_config, context_data,
-                  CustomWorkerContext) as foo:
+                  worker_ctx_cls=CustomWorkerContext) as foo:
         assert foo.get_context_data('custom_header') == "custom_value"
 
     with RpcProxy('foobar', rabbit_config, context_data) as foo:
@@ -231,7 +237,7 @@ class ExampleService(object):
         return arg
 
 
-def test_standalone_proxy_disconnect_with_pending_reply(
+def test_disconnect_with_pending_reply(
         container_factory, rabbit_manager, rabbit_config):
 
     example_container = container_factory(ExampleService, rabbit_config)
@@ -275,6 +281,54 @@ def test_standalone_proxy_disconnect_with_pending_reply(
             assert proxy.method('hello') == 'hello'
 
 
+def test_timeout_not_needed(container_factory, rabbit_manager, rabbit_config):
+    container = container_factory(FooService, rabbit_config)
+    container.start()
+
+    with RpcProxy('foobar', rabbit_config, timeout=1) as proxy:
+        assert proxy.sleep() == 0
+
+
+def test_timeout(container_factory, rabbit_manager, rabbit_config):
+    container = container_factory(FooService, rabbit_config)
+    container.start()
+
+    with RpcProxy('foobar', rabbit_config, timeout=.1) as proxy:
+        with pytest.raises(RpcTimeout):
+            proxy.sleep(seconds=1)
+
+        # make sure we can still use the proxy
+        assert proxy.sleep(seconds=0) == 0
+
+
+def test_no_timeout(
+    container_factory, rabbit_manager, rabbit_config
+):
+    container = container_factory(FooService, rabbit_config)
+    container.start()
+
+    with RpcProxy('foobar', rabbit_config) as proxy:
+        with pytest.raises(eventlet.Timeout):
+            with eventlet.Timeout(.1):
+                proxy.sleep(seconds=1)
+
+
+def test_async_timeout(
+    container_factory, rabbit_manager, rabbit_config
+):
+    container = container_factory(FooService, rabbit_config)
+    container.start()
+
+    with RpcProxy('foobar', rabbit_config, timeout=.1) as proxy:
+        result = proxy.sleep.async(seconds=1)
+        with pytest.raises(RpcTimeout):
+            result.result()
+
+        result = proxy.sleep.async(seconds=.2)
+        eventlet.sleep(.2)
+        result.result()
+
+
 def test_proxy_deletes_queue_even_if_unused(rabbit_manager, rabbit_config):
     vhost = rabbit_config['vhost']
     with RpcProxy('exampleservice', rabbit_config):
