@@ -1,7 +1,9 @@
+# coding: utf-8
+
 from eventlet import GreenPool, sleep
 from eventlet.event import Event
 import pytest
-from nameko.utils import fail_fast_imap
+from nameko.utils import fail_fast_imap, repr_safe_str
 
 
 def test_fail_fast_imap():
@@ -31,3 +33,17 @@ def test_fail_fast_imap():
     # The slow call won't go past the sleep as it was killed
     assert not slow_call_returned.ready()
     assert pool.free() == 2
+
+
+@pytest.mark.parametrize("value, repr_safe_value", [
+    ("bytestr", b"bytestr"),
+    ("bÿtestr", b"b\xc3\xbftestr"),
+    (u"unicode", b"unicode"),
+    (u"unicøde", b"unic\xc3\xb8de"),
+    (None, b"None"),  # cannot encode non-string
+    (object, b"<type 'object'>"),  # cannot encode non-string
+])
+def test_repr_safe_str(value, repr_safe_value):
+    res = repr_safe_str(value)
+    assert res == repr_safe_value
+    assert isinstance(res, bytes)
